InstructLab CLI

Globais

Opções

--project-id (string)
A ID do projeto InstructLab.
--output (string)
Escolha um formato de saída. Pode ser 'json', 'yaml' ou 'table'. O padrão é "table".
-j, --jmes-query (string)
Forneça uma consulta JMESPath para customizar a saída.
-q, --quiet
Suprime mensagens detalhadas.
-v, --version
Imprime a versão do plug-in.

Exemplo

ibmcloud ilab
    --project-id=project_id \
    --output=json \
    --jmes-query="[:10]" \
    --quiet

Observação: este exemplo demonstra apenas as opções globais disponíveis para todos os subcomandos e não é um comando válido em si.

Configuração

Os parâmetros globais também podem ser armazenados em uma configuração persistente para que não precisem ser especificados manualmente sempre que o plug-in for chamado. Cada parâmetro pode ser configurado com o comando config e seus subcomandos.

ibmcloud ilab config

ibmcloud ilab config set

Configurar um novo valor de configuração para uma opção específica. Cada subcomando do comando set mapeia para uma opção global. Cada subcomando aceita um único argumento, a representação em cadeia do valor a ser armazenado para a opção.

ibmcloud ilab config set <option> <value>

Exemplos

ibmcloud ilab config get

Imprime o valor atualmente definido para uma opção específica. Cada subcomando do comando get mapeia para uma opção global.

ibmcloud ilab config get <option>

Exemplos

ibmcloud ilab config unset

Desconfigurar o valor configurado atualmente para uma opção específica. Cada subcomando do comando unset mapeia para uma opção global.

Os subcomandos disponíveis para esse serviço são:.

ibmcloud ilab config unset <option>

Exemplos

ibmcloud ilab config list

Lista todos os valores de configuração definidos atualmente.

ibmcloud ilab config list

Exemplos

ibmcloud ilab config list

Taxonomia

Operações para gerenciar taxonomias.

ibmcloud ilab taxonomy --help

ibmcloud ilab taxonomy add

Adicione uma taxonomia ao seu bucket Cloud Object Storage.

ibmcloud ilab taxonomy add --name NAME [--taxonomy-path TAXONOMY-PATH] [--taxonomy-path-cos TAXONOMY-PATH-COS] [--cos-bucket-information COS-BUCKET-INFORMATION | --cos-id COS-ID --cos-bucket COS-BUCKET --cos-endpoint COS-ENDPOINT] [--secrets-manager-config SECRETS-MANAGER-CONFIG | --secrets-manager-git-url SECRETS-MANAGER-GIT-URL --secrets-manager-git-id SECRETS-MANAGER-GIT-ID]

Opções de comando

--name (string)

O nome que você deseja dar à sua taxonomia. Obrigatório.

O comprimento máximo é de 32 caracteres. O comprimento mínimo é de 1 caracteres. O valor deve corresponder à expressão regular /^[a-zA-Z0-9]([_-]?[a-zA-Z0-9]+)*$/.

--taxonomy-path (string)

O caminho absoluto ou relativo para o arquivo taxonomy.tar.gz em seu computador local. Por exemplo, ' Downloads/taxonomy.tar.gz '.

O comprimento máximo é de 100 caracteres. O comprimento mínimo é de 10 caracteres. O valor deve corresponder à expressão regular /^(?:[a-zA-Z]:\\\\|\\.{0,2}[\\\/]|\/)?(?:[^\\\/:*?"<>|\\r\\n]+[\\\/])*[^\\\/:*?"<>|\\r\\n]*$/.

--taxonomy-path-cos (string)

O caminho em seu bucket Cloud Object Storage onde você deseja armazenar sua taxonomia. Por padrão, as taxonomias são armazenadas em 'taxonomies/taxonomy-<current_time>. tar.gz '.

O comprimento máximo é de 100 caracteres. O comprimento mínimo é de 20 caracteres. O valor deve corresponder à expressão regular /^([-_.\/a-zA-Z0-9][a-zA-Z0-9]+)*[^\/]$/.

--cos-bucket-information (CosBucketInformationPrototype)

Cloud Object Storage informações sobre a caçamba. Em vez disso, essa opção JSON pode ser fornecida definindo campos individuais com outras opções. Ela é mutuamente exclusiva em relação a essas opções.

Forneça uma opção de cadeia de caracteres JSON ou especifique um arquivo JSON para leitura, fornecendo uma opção de caminho de arquivo que comece com @, por exemplo, --cos-bucket-information=@path/to/file.json.

--secrets-manager-config (SecretsManagerConfigPrototype)

Secrets Manager detalhes da configuração. Em vez disso, essa opção JSON pode ser fornecida definindo campos individuais com outras opções. Ela é mutuamente exclusiva em relação a essas opções.

Forneça uma opção de cadeia de caracteres JSON ou especifique um arquivo JSON para leitura, fornecendo uma opção de caminho de arquivo que comece com @, por exemplo, --secrets-manager-config=@path/to/file.json.

--cos-id (string)

Seu ID de instância Cloud Object Storage. Essa opção só é necessária quando você deseja que o InstructLab crie automaticamente um bucket em sua instância do Object Storage. Essa opção fornece um valor para um subcampo da opção JSON "cos-bucket-information". Ela é mutuamente exclusiva dessa opção.

O comprimento máximo é de 100 caracteres. O comprimento mínimo é de 20 caracteres. O valor deve corresponder à expressão regular /^[a-z0-9-]+$/.

-b, --cos-bucket (string)

O Cloud Object Storage bucket onde você deseja armazenar seu taxonomy.tar.gz. Essa opção fornece um valor para um subcampo da opção JSON "cos-bucket-information". Ela é mutuamente exclusiva dessa opção.

O comprimento máximo é de 63 caracteres. O comprimento mínimo é de 3 caracteres. O valor deve corresponder à expressão regular /^[a-zA-Z0-9]([.-]?[a-zA-Z0-9]+)*$/.

-e, --cos-endpoint (string)

O ponto de extremidade para o bucket Cloud Object Storage. Essa opção fornece um valor para um subcampo da opção JSON "cos-bucket-information". Ela é mutuamente exclusiva dessa opção.

O comprimento máximo é de 300 caracteres. O comprimento mínimo é de 13 caracteres. O valor deve corresponder à expressão regular /^https:\/\/([a-zA-Z0-9-]+\\.)*cloud-object-storage(?:\\.test)?\\.appdomain\\.cloud$/.

--secrets-manager-git-url (string)

O endereço URL para uma instância Secrets Manager para recuperar seus segredos definidos pelo usuário. As credenciais em sua instância Secrets Manager são usadas para recuperar os documentos de conhecimento referenciados em sua taxonomia a partir do repositório onde eles estão armazenados. Essa opção fornece um valor para um subcampo da opção JSON "secrets-manager-config". Ela é mutuamente exclusiva dessa opção.

O comprimento máximo é de 300 caracteres. O comprimento mínimo é de 13 caracteres. O valor deve corresponder à expressão regular /^https:\/\/([a-zA-Z0-9-]+\\.)*secrets-manager(?:\\.test)?\\.appdomain\\.cloud$/.

--secrets-manager-git-id (string)

A ID Secrets Manager que aponta para seu token de autorização pessoal e URL no formato JSON. As credenciais em sua instância Secrets Manager são usadas para recuperar os documentos de conhecimento referenciados em sua taxonomia a partir do repositório onde eles estão armazenados. Essa opção fornece um valor para um subcampo da opção JSON "secrets-manager-config". Ela é mutuamente exclusiva dessa opção.

O comprimento máximo é de 36 caracteres. O comprimento mínimo é de 36 caracteres. O valor deve corresponder à expressão regular /^[a-z0-9-]+$/.

Exemplos

ibmcloud ilab taxonomy add \
    --name example-taxonomy-1 \
    --taxonomy-path exampleString \
    --taxonomy-path-cos taxonomies/taxonomy.tar.gz \
    --cos-bucket-information '{"service_instance_id": "628e4348-2183-42fa-a03a-6f0f78453530", "bucket": "example-bucket-1", "endpoint": "https://s3.us-east.cloud-object-storage.appdomain.cloud"}' \
    --secrets-manager-config '{"url": "https://12345678-abcd-1234-5678-abcdefghijkl.us-east.secrets-manager.appdomain.cloud", "git_id": "d9428888-122b-11e1-b85c-61cd3cbb3210"}'

Como alternativa, as opções granulares estão disponíveis para os subcampos das opções de cadeia de caracteres JSON:

ibmcloud ilab taxonomy add \
    --name example-taxonomy-1 \
    --taxonomy-path exampleString \
    --taxonomy-path-cos taxonomies/taxonomy.tar.gz \
    --cos-id 628e4348-2183-42fa-a03a-6f0f78453530 \
    --cos-bucket example-bucket-1 \
    --cos-endpoint https://s3.us-east.cloud-object-storage.appdomain.cloud \
    --secrets-manager-git-url https://12345678-abcd-1234-5678-abcdefghijkl.us-east.secrets-manager.appdomain.cloud \
    --secrets-manager-git-id d9428888-122b-11e1-b85c-61cd3cbb3210

ibmcloud ilab taxonomy list

Lista os detalhes de uma coleção de recursos de taxonomia.

ibmcloud ilab taxonomy list

Exemplo

ibmcloud ilab taxonomy list

Caminho padrão do JMESP

Uma consulta JMESPath será aplicada a essa saída desse comando por padrão, se não for fornecida pelo usuário. A consulta exata dependerá do cenário e do formato de saída solicitado. Você pode ver a condição para cada consulta JMESPath padrão na tabela a seguir:

Caminho padrão do JMESP
Resposta Saída Consultar
Sucesso Padrão
Tabela taxonomies[].{id:id,name:name,taxonomy_path_cos:taxonomy_path_cos,created_at:created_at,state:state,status:status}

Se for fornecida uma consulta JMESPath personalizada, ela substituirá qualquer um dos JMESPath da tabela acima.

ibmcloud ilab taxonomy get

Obtém os detalhes de um recurso de taxonomia.

ibmcloud ilab taxonomy get --id ID

Opções de comando

--id (string)

Identificador exclusivo de uma taxonomia. Obrigatório.

O comprimento máximo é de 36 caracteres. O comprimento mínimo é de 36 caracteres. O valor deve corresponder à expressão regular /^[a-z0-9-]+$/.

Exemplo

ibmcloud ilab taxonomy get \
    --id 817bc95a-fef0-4039-b936-e0b6fb17b723

Caminho padrão do JMESP

Uma consulta JMESPath será aplicada a essa saída desse comando por padrão, se não for fornecida pelo usuário. A consulta exata dependerá do cenário e do formato de saída solicitado. Você pode ver a condição para cada consulta JMESPath padrão na tabela a seguir:

Caminho padrão do JMESP
Resposta Saída Consultar
Sucesso Padrão
Tabela {id:id,name:name,project_id:project_id,taxonomy_path_cos:taxonomy_path_cos,created_at:created_at,state:state,status:status}

Se for fornecida uma consulta JMESPath personalizada, ela substituirá qualquer um dos JMESPath da tabela acima.

ibmcloud ilab taxonomy delete

Exclui um recurso de taxonomia.

ibmcloud ilab taxonomy delete --id ID

Opções de comando

--id (string)

Identificador exclusivo de uma taxonomia. Obrigatório.

O comprimento máximo é de 36 caracteres. O comprimento mínimo é de 36 caracteres. O valor deve corresponder à expressão regular /^[a-z0-9-]+$/.

Exemplo

ibmcloud ilab taxonomy delete \
    --id 817bc95a-fef0-4039-b936-e0b6fb17b723

Dados

Operações para gerenciar dados.

ibmcloud ilab data --help

ibmcloud ilab data generate

Gera dados em relação a um recurso de taxonomia especificado.

ibmcloud ilab data generate --name NAME [--taxonomy-id TAXONOMY-ID] [--data-destination DATA-DESTINATION | --output-cos-bucket OUTPUT-COS-BUCKET --output-cos-endpoint OUTPUT-COS-ENDPOINT] [--data-sources DATA-SOURCES | --internal-ids INTERNAL-IDS --skills-paths SKILLS-PATHS --knowledge-paths KNOWLEDGE-PATHS --skills-knowledge-cos-bucket SKILLS-KNOWLEDGE-COS-BUCKET --skills-knowledge-cos-endpoint SKILLS-KNOWLEDGE-COS-ENDPOINT --data-sources-user-provided-paths DATA-SOURCES-USER-PROVIDED-PATHS]

Opções de comando

--name (string)

O nome a ser dado a um recurso de dados. Obrigatório.

O comprimento máximo é de 32 caracteres. O comprimento mínimo é de 1 caracteres. O valor deve corresponder à expressão regular /^[a-zA-Z0-9]([_-]?[a-zA-Z0-9]+)*$/.

--taxonomy-id (string)

A ID da taxonomia que foi usada para a geração de dados sintéticos. No treinamento do modelo, esse valor é usado para validar a ID de dados. Esse valor está disponível somente depois que o trabalho de treinamento do modelo é aceito por um agente.

O comprimento máximo é de 36 caracteres. O comprimento mínimo é de 36 caracteres. O valor deve corresponder à expressão regular /^[a-z0-9-]+$/.

--data-destination (DataDestinationPrototype)

Saída Cloud Object Storage informações sobre o bucket. Em vez disso, essa opção JSON pode ser fornecida definindo campos individuais com outras opções. Ela é mutuamente exclusiva em relação a essas opções.

Forneça uma opção de cadeia de caracteres JSON ou especifique um arquivo JSON para leitura, fornecendo uma opção de caminho de arquivo que comece com @, por exemplo, --data-destination=@path/to/file.json.

--data-sources (DataSourcesPrototype)

Fontes de dados associadas à taxonomia. Em vez disso, essa opção JSON pode ser fornecida definindo campos individuais com outras opções. Ela é mutuamente exclusiva em relação a essas opções.

Forneça uma opção de cadeia de caracteres JSON ou especifique um arquivo JSON para leitura, fornecendo uma opção de caminho de arquivo que comece com @, por exemplo, --data-sources=@path/to/file.json.

--output-cos-bucket (string)

O endereço Cloud Object Storage em que a saída será armazenada. Essa opção fornece um valor para um subcampo da opção JSON 'data-destination'. Ela é mutuamente exclusiva dessa opção.

O comprimento máximo é de 63 caracteres. O comprimento mínimo é de 3 caracteres. O valor deve corresponder à expressão regular /^[a-zA-Z0-9]([.-]?[a-zA-Z0-9]+)*$/.

--output-cos-endpoint (string)

O ponto de extremidade para o bucket de saída Cloud Object Storage. Essa opção fornece um valor para um subcampo da opção JSON 'data-destination'. Ela é mutuamente exclusiva dessa opção.

O comprimento máximo é de 300 caracteres. O comprimento mínimo é de 13 caracteres. O valor deve corresponder à expressão regular /^https:\/\/([a-zA-Z0-9-]+\\.)*cloud-object-storage(?:\\.test)?\\.appdomain\\.cloud$/.

--internal-ids ([]strfmt.UUID)

Lista de UUIDs internos que fazem referência a fontes de dados. Essa opção fornece um valor para um subcampo da opção JSON 'data-sources'. Ela é mutuamente exclusiva dessa opção.

Os itens da lista devem corresponder à expressão regular /^[a-z0-9-]+$/. O tamanho máximo é 20 itens. O tamanho mínimo é 0 itens.

--skills-paths ([]string)

Um conjunto de arquivos json de habilidades fornecidas pelo usuário presentes em um bucket autorizado do Cloud Object Storage que contém dados selecionados para ajuste fino. Cada arquivo não deve exceder 100 GB de tamanho. O tamanho acumulado de todos os arquivos json de habilidades e conhecimentos (incluindo os arquivos de ids internos, se fornecidos) não deve exceder 400 GB. Essa opção fornece um valor para um subcampo da opção JSON 'data-sources'. Ela é mutuamente exclusiva dessa opção.

Os itens da lista devem corresponder à expressão regular /^([-_.\/a-zA-Z0-9][a-zA-Z0-9]+)*[^\/]$/. O tamanho máximo é 20 itens. O tamanho mínimo é 0 itens.

--knowledge-paths ([]string)

Um conjunto de arquivos json de conhecimento fornecidos pelo usuário presentes em um bucket autorizado do Cloud Object Storage que contém dados selecionados para ajuste fino. Cada arquivo não deve exceder 100 GB de tamanho. O tamanho acumulado de todos os arquivos json de habilidades e conhecimentos (incluindo os arquivos de ids internos, se fornecidos) não deve exceder 400 GB. Essa opção fornece um valor para um subcampo da opção JSON 'data-sources'. Ela é mutuamente exclusiva dessa opção.

Os itens da lista devem corresponder à expressão regular /^([-_.\/a-zA-Z0-9][a-zA-Z0-9]+)*[^\/]$/. O tamanho máximo é 20 itens. O tamanho mínimo é 0 itens.

--skills-knowledge-cos-bucket (string)

O bucket Cloud Object Storage onde o jsonl de habilidades/conhecimento está armazenado. Essa opção fornece um valor para um subcampo da opção JSON 'data-sources'. Ela é mutuamente exclusiva dessa opção.

O comprimento máximo é de 63 caracteres. O comprimento mínimo é de 3 caracteres. O valor deve corresponder à expressão regular /^[a-zA-Z0-9]([.-]?[a-zA-Z0-9]+)*$/.

--skills-knowledge-cos-endpoint (string)

O ponto de extremidade para o bucket Cloud Object Storage. Essa opção fornece um valor para um subcampo da opção JSON 'data-sources'. Ela é mutuamente exclusiva dessa opção.

O comprimento máximo é de 300 caracteres. O comprimento mínimo é de 13 caracteres. O valor deve corresponder à expressão regular /^https:\/\/([a-zA-Z0-9-]+\\.)*cloud-object-storage(?:\\.test)?\\.appdomain\\.cloud$/.

--data-sources-user-provided-paths (UserProvidedPathsPrototype)

Caminhos de arquivo fornecidos pelo usuário para dados de treinamento de habilidades e conhecimentos. Cada arquivo não deve exceder 100 GB de tamanho. O tamanho acumulado de todos os arquivos json de habilidades e conhecimentos (incluindo os arquivos de ids internos, se fornecidos) não deve exceder 400 GB. Essa opção fornece um valor para um subcampo da opção JSON 'data-sources'. Ela é mutuamente exclusiva dessa opção.

Forneça uma opção de cadeia de caracteres JSON ou especifique um arquivo JSON para leitura, fornecendo uma opção de caminho de arquivo que comece com @, por exemplo, --data-sources-user-provided-paths=@path/to/file.json.

Exemplos

ibmcloud ilab data generate \
    --name example-data-1 \
    --taxonomy-id 202a03c4-dcf1-432a-82b7-abecb2e019f7 \
    --data-destination '{"bucket": "example-bucket-1", "endpoint": "https://s3.us-east.cloud-object-storage.appdomain.cloud"}' \
    --data-sources '{"internal_ids": ["9e0a5988-0c7d-44de-ba48-465aef67baee","9e0a5988-0c7d-44de-ba48-465aef67baee"], "skills": ["user_provided_path/skills/skills_1.jsonl","user_provided_path/skills/skills_1.jsonl"], "knowledge": ["user_provided_path/knowledge/knowledge1.jsonl","user_provided_path/knowledge/knowledge1.jsonl"], "bucket": "example-bucket-1", "endpoint": "https://s3.us-east.cloud-object-storage.appdomain.cloud", "user_provided_paths": {"skills": ["user_provided_path/skills/skills_1.jsonl","user_provided_path/skills/skills_1.jsonl"], "knowledge": ["user_provided_path/knowledge/knowledge1.jsonl","user_provided_path/knowledge/knowledge1.jsonl"], "cos_bucket_information": {"bucket": "example-bucket-1", "endpoint": "https://s3.us-east.cloud-object-storage.appdomain.cloud"}}}'

Como alternativa, as opções granulares estão disponíveis para os subcampos das opções de cadeia de caracteres JSON:

ibmcloud ilab data generate \
    --name example-data-1 \
    --taxonomy-id 202a03c4-dcf1-432a-82b7-abecb2e019f7 \
    --output-cos-bucket example-bucket-1 \
    --output-cos-endpoint https://s3.us-east.cloud-object-storage.appdomain.cloud \
    --internal-ids 9e0a5988-0c7d-44de-ba48-465aef67baee,9e0a5988-0c7d-44de-ba48-465aef67baee \
    --skills-paths user_provided_path/skills/skills_1.jsonl,user_provided_path/skills/skills_1.jsonl \
    --knowledge-paths user_provided_path/knowledge/knowledge1.jsonl,user_provided_path/knowledge/knowledge1.jsonl \
    --skills-knowledge-cos-bucket example-bucket-1 \
    --skills-knowledge-cos-endpoint https://s3.us-east.cloud-object-storage.appdomain.cloud \
    --data-sources-user-provided-paths userProvidedPathsPrototype

ibmcloud ilab data list

Lista os detalhes de uma coleção de recursos de dados.

ibmcloud ilab data list

Exemplo

ibmcloud ilab data list

Caminho padrão do JMESP

Uma consulta JMESPath será aplicada a essa saída desse comando por padrão, se não for fornecida pelo usuário. A consulta exata dependerá do cenário e do formato de saída solicitado. Você pode ver a condição para cada consulta JMESPath padrão na tabela a seguir:

Caminho padrão do JMESP
Resposta Saída Consultar
Sucesso Padrão
Tabela data[].{id:id,name:name,state:state,status:status,created_at:created_at,completed_at:completed_at}

Se for fornecida uma consulta JMESPath personalizada, ela substituirá qualquer um dos JMESPath da tabela acima.

ibmcloud ilab data get

Obtém os detalhes de um recurso de dados.

ibmcloud ilab data get --id ID

Opções de comando

--id (string)

Identificador exclusivo para execução de dados. Obrigatório.

O comprimento máximo é de 36 caracteres. O comprimento mínimo é de 36 caracteres. O valor deve corresponder à expressão regular /^[a-z0-9-]+$/.

Exemplo

ibmcloud ilab data get \
    --id 817bc95a-fef0-4039-b936-e0b6fb17b723

Caminho padrão do JMESP

Uma consulta JMESPath será aplicada a essa saída desse comando por padrão, se não for fornecida pelo usuário. A consulta exata dependerá do cenário e do formato de saída solicitado. Você pode ver a condição para cada consulta JMESPath padrão na tabela a seguir:

Caminho padrão do JMESP
Resposta Saída Consultar
Sucesso Padrão
Tabela {id:id,name:name,project_id:project_id,state:state,status:status,created_at:created_at,completed_at:completed_at}

Se for fornecida uma consulta JMESPath personalizada, ela substituirá qualquer um dos JMESPath da tabela acima.

ibmcloud ilab data delete

Exclui um recurso de dados.

ibmcloud ilab data delete --id ID

Opções de comando

--id (string)

Identificador exclusivo para execução de dados. Obrigatório.

O comprimento máximo é de 36 caracteres. O comprimento mínimo é de 36 caracteres. O valor deve corresponder à expressão regular /^[a-z0-9-]+$/.

Exemplo

ibmcloud ilab data delete \
    --id 817bc95a-fef0-4039-b936-e0b6fb17b723

ibmcloud ilab data cancel

Cancela a geração de dados sintéticos.

ibmcloud ilab data cancel --id ID

Opções de comando

--id (string)

Identificador exclusivo para execução de dados. Obrigatório.

O comprimento máximo é de 36 caracteres. O comprimento mínimo é de 36 caracteres. O valor deve corresponder à expressão regular /^[a-z0-9-]+$/.

Exemplo

ibmcloud ilab data cancel \
    --id 817bc95a-fef0-4039-b936-e0b6fb17b723

Modelo

Operações para gerenciar modelos.

ibmcloud ilab model --help

ibmcloud ilab model train

Treina um modelo com base nos dados sintéticos especificados.

ibmcloud ilab model train --name NAME --data-id DATA-ID

Opções de comando

--name (string)

O nome a ser dado a um recurso de modelo. Obrigatório.

O comprimento máximo é de 32 caracteres. O comprimento mínimo é de 1 caracteres. O valor deve corresponder à expressão regular /^[a-zA-Z0-9]([_-]?[a-zA-Z0-9]+)*$/.

--data-id (string)

A ID da execução da geração de dados sintéticos (SDG). Você pode usar esse ID para monitorar o processo de geração de dados. Após a conclusão do SDG, você pode usar esse ID para recuperar os dados sintéticos. Obrigatório.

O comprimento máximo é de 36 caracteres. O comprimento mínimo é de 36 caracteres. O valor deve corresponder à expressão regular /^[a-z0-9-]+$/.

Exemplo

ibmcloud ilab model train \
    --name example-model-1 \
    --data-id add785e6-a8c3-4f5f-ab89-c506a3f115da

ibmcloud ilab model list

Lista seus recursos de modelo.

ibmcloud ilab model list

Exemplo

ibmcloud ilab model list

Caminho padrão do JMESP

Uma consulta JMESPath será aplicada a essa saída desse comando por padrão, se não for fornecida pelo usuário. A consulta exata dependerá do cenário e do formato de saída solicitado. Você pode ver a condição para cada consulta JMESPath padrão na tabela a seguir:

Caminho padrão do JMESP
Resposta Saída Consultar
Sucesso Padrão
Tabela models[].{created_at:created_at,completed_at:completed_at,id:id,name:name,state:state,status:status}

Se for fornecida uma consulta JMESPath personalizada, ela substituirá qualquer um dos JMESPath da tabela acima.

ibmcloud ilab model get

Obtém os detalhes de um modelo.

ibmcloud ilab model get --id ID

Opções de comando

--id (string)

Identificador exclusivo de uma execução de treinamento de modelo. Obrigatório.

O comprimento máximo é de 36 caracteres. O comprimento mínimo é de 36 caracteres. O valor deve corresponder à expressão regular /^[a-z0-9-]+$/.

Exemplo

ibmcloud ilab model get \
    --id 817bc95a-fef0-4039-b936-e0b6fb17b723

Caminho padrão do JMESP

Uma consulta JMESPath será aplicada a essa saída desse comando por padrão, se não for fornecida pelo usuário. A consulta exata dependerá do cenário e do formato de saída solicitado. Você pode ver a condição para cada consulta JMESPath padrão na tabela a seguir:

Caminho padrão do JMESP
Resposta Saída Consultar
Sucesso Padrão
Tabela {base_model:base_model,created_at:created_at,completed_at:completed_at,data_id:data_id,id:id,name:name,project_id:project_id,state:state,status:status}

Se for fornecida uma consulta JMESPath personalizada, ela substituirá qualquer um dos JMESPath da tabela acima.

ibmcloud ilab model delete

Excluir um modelo.

ibmcloud ilab model delete --id ID

Opções de comando

--id (string)

Identificador exclusivo de uma execução de treinamento de modelo. Obrigatório.

O comprimento máximo é de 36 caracteres. O comprimento mínimo é de 36 caracteres. O valor deve corresponder à expressão regular /^[a-z0-9-]+$/.

Exemplo

ibmcloud ilab model delete \
    --id 817bc95a-fef0-4039-b936-e0b6fb17b723

ibmcloud ilab model cancel

Cancela o treinamento de um modelo.

ibmcloud ilab model cancel --id ID

Opções de comando

--id (string)

Identificador exclusivo de uma execução de treinamento de modelo. Obrigatório.

O comprimento máximo é de 36 caracteres. O comprimento mínimo é de 36 caracteres. O valor deve corresponder à expressão regular /^[a-z0-9-]+$/.

Exemplo

ibmcloud ilab model cancel \
    --id 817bc95a-fef0-4039-b936-e0b6fb17b723

Exemplos de esquema

Os exemplos de esquema a seguir representam os dados que precisam ser especificados para uma opção de comando. Esses exemplos modelam a estrutura de dados e incluem valores de item temporário para o tipo de valor esperado. Ao executar um comando, substitua esses valores pelos valores que se aplicam ao seu ambiente, conforme apropriado.

CosBucketInformationPrototype

O exemplo a seguir mostra o formato do objeto CosBucketInformationPrototype.


{
  "service_instance_id" : "628e4348-2183-42fa-a03a-6f0f78453530",
  "bucket" : "example-bucket-1",
  "endpoint" : "https://s3.us-east.cloud-object-storage.appdomain.cloud"
}

DataDestinationPrototype

O exemplo a seguir mostra o formato do objeto DataDestinationPrototype.


{
  "bucket" : "example-bucket-1",
  "endpoint" : "https://s3.us-east.cloud-object-storage.appdomain.cloud"
}

DataSourcesPrototype

O exemplo a seguir mostra o formato do objeto DataSourcesPrototype.


{
  "internal_ids" : [ "9e0a5988-0c7d-44de-ba48-465aef67baee", "9e0a5988-0c7d-44de-ba48-465aef67baee" ],
  "skills" : [ "user_provided_path/skills/skills_1.jsonl", "user_provided_path/skills/skills_1.jsonl" ],
  "knowledge" : [ "user_provided_path/knowledge/knowledge1.jsonl", "user_provided_path/knowledge/knowledge1.jsonl" ],
  "bucket" : "example-bucket-1",
  "endpoint" : "https://s3.us-east.cloud-object-storage.appdomain.cloud",
  "user_provided_paths" : {
    "skills" : [ "user_provided_path/skills/skills_1.jsonl", "user_provided_path/skills/skills_1.jsonl" ],
    "knowledge" : [ "user_provided_path/knowledge/knowledge1.jsonl", "user_provided_path/knowledge/knowledge1.jsonl" ],
    "cos_bucket_information" : {
      "bucket" : "example-bucket-1",
      "endpoint" : "https://s3.us-east.cloud-object-storage.appdomain.cloud"
    }
  }
}

SecretsManagerConfigPrototype

O exemplo a seguir mostra o formato do objeto SecretsManagerConfigPrototype.


{
  "url" : "https://12345678-abcd-1234-5678-abcdefghijkl.us-east.secrets-manager.appdomain.cloud",
  "git_id" : "d9428888-122b-11e1-b85c-61cd3cbb3210"
}

UserProvidedPathsPrototype

O exemplo a seguir mostra o formato do objeto UserProvidedPathsPrototype.


{
  "bucket" : "example-bucket-1",
  "endpoint" : "https://s3.us-east.cloud-object-storage.appdomain.cloud"
}